@@ -4,7 +4,6 @@ use citi::{
 };
 use num_complex::Complex;
 use std::fs::File;
-use std::io::BufReader;
 use std::path::PathBuf;
 
 #[cfg(test)]
@@ -29,8 +28,8 @@ mod cti_read_regression_tests {
         }
 
         fn setup() -> Result<Record> {
-            let mut file = BufReader::new(File::open(filename()).unwrap());
-            Record::read_from_source(&mut file)
+            let mut file = File::open(filename()).unwrap();
+            Record::from_reader(&mut file)
         }
 
         #[test]
@@ -141,8 +140,8 @@ mod cti_read_regression_tests {
         }
 
         fn setup() -> Result<Record> {
-            let mut file = BufReader::new(File::open(filename()).unwrap());
-            Record::read_from_source(&mut file)
+            let mut file = File::open(filename()).unwrap();
+            Record::from_reader(&mut file)
         }
 
         #[test]
@@ -291,8 +290,8 @@ mod cti_read_regression_tests {
         }
 
         fn setup() -> Result<Record> {
-            let mut file = BufReader::new(File::open(filename()).unwrap());
-            Record::read_from_source(&mut file)
+            let mut file = File::open(filename()).unwrap();
+            Record::from_reader(&mut file)
         }
 
         #[test]
@@ -402,8 +401,8 @@ mod cti_read_regression_tests {
         }
 
         fn setup() -> Result<Record> {
-            let mut file = BufReader::new(File::open(filename()).unwrap());
-            Record::read_from_source(&mut file)
+            let mut file = File::open(filename()).unwrap();
+            Record::from_reader(&mut file)
         }
 
         #[test]
@@ -623,7 +622,7 @@ mod cti_write_regression_tests {
         let filename = tmp.path().join("temp-display-memory.cti");
         let mut file = File::create(filename.clone()).unwrap();
         let record = display_memory_record();
-        record.write_to_sink(&mut file).unwrap();
+        record.to_writer(&mut file).unwrap();
 
         assert_files_equal!(display_memory_filename(), filename);
     }
